# SimpleResourcePolicyTemplateStructure

Associates the tree (made of Nodes) with metadata like a name. The name uniquely identifies the SimpleResourcePolicyTemplateStructure within the template. The root_node is the root of the tree. 

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**name** | [**StandaloneRuleName**](StandaloneRuleName.md) |  | 
**root_node** | [**SimpleResourcePolicyTemplateStructureNode**](SimpleResourcePolicyTemplateStructureNode.md) |  | 
**any string name** | **bool, date, datetime, dict, float, int, list, str, none_type** | any string name can be used but the value must be the correct type | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


